; Copyright (C) 2023  Val Lorentz
; 
; This program is free software: you can redistribute it and/or modify it under the
; terms of the GNU Affero General Public License version 3, as published by the Free
; Software Foundation.
; 
; This program is distributed in the hope that it will be useful, but WITHOUT ANY
; WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
; PARTICULAR PURPOSE.  See the GNU Affero General Public License for more details.
; 
; You should have received a copy of the GNU Affero General Public License along with
; this program.  If not, see <http://www.gnu.org/licenses/>.

(ns jable.cli
  (:require [jepsen.cli :as cli]
            [jepsen.tests :as tests]
            [jepsen.os.debian :as debian]
            [jable.db :as db]))

(defn sable-test
  "Given an options map from the command line runner (e.g. :nodes, :ssh,
  :concurrency, ...), constructs a test map."
  [opts]
  (merge tests/noop-test
         opts
         {:name "etcd"
          :os   debian/os
          :db   (db/sable (:sable-bin opts) (:nodes opts))
          :pure-generators true}))

(def cli-opts
  "Additional command line options."
  [[nil "--sable-bin SABLE/BIN/" "Path to a directory containing Sable's binary (eg. ~/sable/target/debug/)"]])

(defn -main
  "Handles command line arguments. Can either run a test, or a web server for
  browsing results."
  [& args]
  (cli/run! (merge (cli/single-test-cmd {:test-fn sable-test
                                         :opt-spec cli-opts})
                   (cli/serve-cmd))
            args))
